# The Base Consumer Class

## Consumer

::: uplink.Consumer
    options:
        members:
            - exceptions
            - session
        inherited_members: false

## Session

::: uplink.session.Session
    options:
        members:
            - auth
            - base_url
            - context
            - headers
            - inject
            - params
